"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _events = _interopRequireDefault(require("events"));

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _lodash = _interopRequireDefault(require("lodash.isequal"));

var _helpers = require("../../shared/helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Default reporter
 * @extends EventEmitter
 */
class FileReporter extends _events.default {
  /**
   * @param {Object} config
   */
  constructor(config) {
    super();
    this._config = config;
    this._results = [];
    this.on('scenario:end', eventData => this._handleScenarioEnd(eventData));
  }
  /**
   * Handler for scenario:end event
   * @param {Object} eventData
   */


  _handleScenarioEnd(eventData) {
    if (eventData.type === 'failing') {
      this._handleFailingScenarioEnd(eventData);
    }
  }
  /**
   * Handler for scenario:end of type 'failing'
   * @param {Object} eventData
   */


  _handleFailingScenarioEnd({
    minified,
    scenario,
    errors
  }) {
    if (this._isFailureReported(scenario)) {
      return;
    }

    this._results.push({
      scenario,
      errors
    });

    this._logFile(scenario, errors, this._getScenarioName(minified ? '-minified' : '-not-reproduced'));
  }
  /**
   * Logs scenario to file
   * @param {Object[]} scenario
   * @param {Object[]} errors
   * @param {string} name
   */


  _logFile(scenario, errors, name) {
    if (!name) {
      name = this._getScenarioName();
    }

    if (!_fs.default.existsSync(this._config.reportPath)) {
      _fs.default.mkdirSync(this._config.reportPath);
    }

    let filePath = _path.default.join(this._config.reportPath, name + '.json');

    let i = 0;

    while (_fs.default.existsSync(filePath)) {
      i++;
      filePath = _path.default.join(this._config.reportPath, name + ` (${i}).json`);
    }

    _fs.default.writeFileSync(filePath, JSON.stringify({
      name,
      errors,
      scenario
    }, null, '\t'));
  }
  /**
   * Generates scenario name from current date
   * @param {string} [extension=] This string
   * will be added to the end of the name
   * @returns {string}
   */


  _getScenarioName(extension = '') {
    let date = new Date();
    return [date.getFullYear(), (0, _helpers.formatDigits)(date.getMonth() + 1), (0, _helpers.formatDigits)(date.getDate()), (0, _helpers.formatDigits)(date.getHours()), (0, _helpers.formatDigits)(date.getMinutes()), (0, _helpers.formatDigits)(date.getSeconds()), (0, _helpers.formatDigits)(date.getMilliseconds(), 3)].join('-') + extension;
  }
  /**
   * Checks if provided scenario is already reported
   * @returns {boolean}
   */


  _isFailureReported(scenario) {
    return !!this._results.find(result => (0, _lodash.default)(result.scenario, scenario));
  }

}

exports.default = FileReporter;