"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _events = _interopRequireDefault(require("events"));

var _readline = require("readline");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const spinner = ['[    ]', '[=   ]', '[==  ]', '[=== ]', '[ ===]', '[  ==]', '[   =]'];
/**
 * Default reporter
 * @extends EventEmitter
 */

class SpinnerReporter extends _events.default {
  /**
   * @param {Object} config
   * @param {Object} stdout
   */
  constructor(config, stdout) {
    super();
    this._config = config;
    this._stdout = stdout || process.stdout;
    this._index = 0;

    if (!this._stdout.isTTY) {
      return;
    }

    this.on('runner:start', () => this._handleEvent());
    this.on('scenario:start', () => this._handleEvent());
    this.on('action:start', () => this._handleEvent());
    this.on('scenario:end', () => this._handleEvent());
    this.on('runner:end', () => this._handleRunnerEnd());
  }
  /**
   * Handler for events which should cause a spin
   */


  _handleEvent() {
    this._clearSpinner();

    this._stdout.write(spinner[this._index]);

    (0, _readline.cursorTo)(this._stdout, 0, this._stdout.rows - 1);
    this._index++;

    if (this._index >= spinner.length) {
      this._index = 0;
    }
  }

  _handleRunnerEnd() {
    this._clearSpinner();
  }

  _clearSpinner() {
    (0, _readline.cursorTo)(this._stdout, 0, this._stdout.rows);
    (0, _readline.clearLine)(this._stdout, 0);
  }

}

exports.default = SpinnerReporter;