"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _DefinedScenarios = _interopRequireDefault(require("./DefinedScenarios"));

var _RandomScenarios = _interopRequireDefault(require("./RandomScenarios"));

var _FailingScenarios = _interopRequireDefault(require("./FailingScenarios"));

var _ScenariosHelper = _interopRequireDefault(require("./ScenariosHelper"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Handles scenarios execution and
 * initializes necessary dependencies
 */
class ScenariosHandler {
  /**
   * @param {Object} config
   * @param {ActionsHandler} actionsHandler
   */
  constructor(config, actionsHandler) {
    this._config = config;
    this._actionsHandler = actionsHandler;
    this._scenariosHelper = null;
    this._definedScenarios = null;
    this._failingScenarios = null;
    this._randomScenarios = null;
  }
  /**
   * Initializes all dependencies
   * @returns {ScenariosHandler}
   */


  init() {
    this._scenariosHelper = new _ScenariosHelper.default(this._config, this._actionsHandler);
    this._definedScenarios = new _DefinedScenarios.default(this._config, this._scenariosHelper);
    this._failingScenarios = new _FailingScenarios.default(this._config, this._scenariosHelper);
    this._randomScenarios = new _RandomScenarios.default(this._config, this._actionsHandler);
    return this;
  }

  runScenario(instance, type, scenario) {
    if (type === 'defined') {
      return this._definedScenarios.runScenario(instance, scenario);
    }

    if (type === 'failing') {
      return this._failingScenarios.runScenario(instance, scenario);
    }

    return this._randomScenarios.runScenario(instance, scenario);
  }

}

exports.default = ScenariosHandler;